_`umbra.ui.widgets.active_QLabelsCollection`
============================================

.. automodule:: umbra.ui.widgets.active_QLabelsCollection

Module Attributes
-----------------

.. attribute:: umbra.ui.widgets.active_QLabelsCollection.LOGGER

Classes
-------

.. autoclass:: Active_QLabelsCollection
	:show-inheritance:
	:members:

